@@ -9,7 +9,7 @@ use constant DEFAULT_MAXPROCS      => 1;
 use constant DEFAULT_REAP_TIMEOUT  => .1;
 use constant DEFAULT_TOTALPROCS    => 1;
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 =head1 NAME
 
@@ -147,7 +147,7 @@ sub waitqueue {
 
     # check for any stopping conditions
     return 0 unless $self->{_continue};
-    return 0 if $self->{_totalprocs} <= 0;
+    return 0 if defined $self->{_totalprocs} and $self->{_totalprocs} <= 0;
 
     # wait to reap at least one child
     while (keys(%{ $self->{_jobs} }) >= $self->{_maxprocs}) {
